import { Component, OnInit, Inject } from '@angular/core';
import { MatDialogRef, MAT_DIALOG_DATA } from '@angular/material';

import { Course } from '@app/core/models/course';
import { SavedForLaterCourse } from '@app/core/models/saved-for-later-course';

import { DegreePlannerState } from '@app/degree-planner/store/state';
import { Store } from '@ngrx/store';

import { RemoveCourseRequest } from '@app/degree-planner/store/actions/plan.actions';

@Component({
  selector: 'cse-remove-course-confirm-dialog',
  templateUrl: './remove-course-confirm-dialog.component.html',
  styleUrls: ['./remove-course-confirm-dialog.component.scss'],
})
export class RemoveCourseConfirmDialogComponent implements OnInit {
  course: Course;
  savedForLater: Boolean;
  courses: Course[];
  type: 'saved' | 'course' | 'search';
  favoriteCourses: SavedForLaterCourse[];

  constructor(
    private dialogRef: MatDialogRef<RemoveCourseConfirmDialogComponent>,
    private store: Store<{ degreePlanner: DegreePlannerState }>,
    @Inject(MAT_DIALOG_DATA) data: any,
  ) {
    this.course = data.course;
    this.type = data.type;
  }

  ngOnInit() {}

  removeCourse() {
    switch (this.type) {
      case 'saved':
        console.log('remove course from saved');
        break;

      case 'course':
        console.log('remove course from term');
        console.log(this.course);
        const id = this.course.id;
        if (typeof id === 'number') {
          this.store.dispatch(new RemoveCourseRequest({ id }));
        } else {
          throw new Error('cannot remove a course that does not have an ID');
        }
        break;
    }
  }
}
